@@ -9,8 +9,8 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.064_01-1-g7825ddf
-$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.065';
+# git description: 0.065-3-g3b32f6b
+$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.066';
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
 
@@ -260,7 +260,7 @@ sub configure {
             Manifest
             SurgicalPkgVersion
             MinimumPerl
-            ReportVersions::Tiny
+            Test::ReportPrereqs
         },
         [ AutoPrereqs => $autoprereq_opts ],
         [ Prepender   => $prepender_opts  ],
@@ -335,6 +335,8 @@ sub stopwords {
         parameterization
         parameterized
         subclasses
+        Formattable
+        formattable
     };
 }
 
@@ -357,7 +359,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.065 of Dist::Zilla::PluginBundle::RSRCHBOY - released July 12, 2015 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.066 of Dist::Zilla::PluginBundle::RSRCHBOY - released August 07, 2015 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
